==> cresce_ui-0.4.1.tar.gz: lib/src/c_header.dart <==
part of cresce_ui;

class CHeader extends StatelessWidget {
  final Uint8List? image;
  final String title;

  const CHeader({Key? key, this.image, required this.title}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Row(
          children: [
            _CHeaderLeft(image: image),
            const SizedBox(width: 8.0),
            const Expanded(child: _CHeaderRight()),
          ],
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            SizedBox(
              height: 50.0,
              child: Center(
                child: CText(label: title, style: CTextStyles.captionSecondary),
              ),
            ),
          ],
        ),
      ],
    );
  }
}

class _CHeaderLeft extends StatelessWidget {
  final Uint8List? image;

  const _CHeaderLeft({Key? key, this.image}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          width: 77.0,
          height: 50.0,
          decoration: BoxDecoration(
            border: Border.all(width: 1.0, color: const Color(0xFF4CBAAC)),
            borderRadius: const BorderRadius.only(
                topRight: Radius.circular(25.0),
                bottomRight: Radius.circular(25.0)),
            color: const Color(0xFFFFFFFF),
            boxShadow: const [
              BoxShadow(
                color: Color(0x29000000),
                offset: Offset(0, 3),
                blurRadius: 6,
              ),
            ],
          ),
          child: Image.memory(image ?? base64Decode(_placeholder)),
        ),
      ],
    );
  }
}

class _CHeaderRight extends StatelessWidget {
  const _CHeaderRight({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50.0,
      decoration: const BoxDecoration(
        borderRadius: BorderRadius.only(
            topLeft: Radius.circular(25.0), bottomLeft: Radius.circular(25.0)),
        color: Color(0xFF4CBAAC),
        boxShadow: [
          BoxShadow(
            color: Color(0x29000000),
            offset: Offset(0, 3),
            blurRadius: 6,
          ),
        ],
      ),
    );
  }
}

==> cresce_ui-0.8.14.tar.gz: lib/src/c_header.dart <==
part of cresce_ui;

class CHeader extends StatelessWidget {
  final Uint8List? image;
  final String title;

  const CHeader({Key? key, this.image, required this.title}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Row(
          children: [
            _CHeaderLeft(image: image),
            const SizedBox(width: 8.0),
            const Expanded(child: _CHeaderRight()),
          ],
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            SizedBox(
              height: 50.0,
              child: Center(
                child: CText(label: title, style: CTextStyles.captionSecondary),
              ),
            ),
          ],
        ),
      ],
    );
  }
}

class _CHeaderLeft extends StatelessWidget {
  final Uint8List? image;

  const _CHeaderLeft({Key? key, this.image}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          width: 77.0,
          height: 50.0,
          decoration: BoxDecoration(
            border: Border.all(width: 1.0, color: CColors.primary),
            borderRadius: const BorderRadius.only(
              topRight: Radius.circular(25.0),
              bottomRight: Radius.circular(25.0),
            ),
            color: CColors.secondary,
            boxShadow: const [CBoxShadow()],
          ),
          child: Image.memory(image ?? base64Decode(_placeholder)),
        ),
      ],
    );
  }
}

class _CHeaderRight extends StatelessWidget {
  const _CHeaderRight({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50.0,
      decoration: BoxDecoration(
        borderRadius: const BorderRadius.only(
          topLeft: Radius.circular(25.0),
          bottomLeft: Radius.circular(25.0),
        ),
        color: CColors.primary,
        boxShadow: const [CBoxShadow()],
      ),
    );
  }
}
